"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.originMiddleware = void 0;
const metric_events_1 = require("../metric-events");
const originMiddleware = ({ getLogger, eventBus, flagResolver, }) => {
    const logger = getLogger('/middleware/origin-middleware.ts');
    logger.debug('Enabling origin middleware');
    return (req, _, next) => {
        if (!flagResolver.isEnabled('originMiddleware')) {
            return next();
        }
        const isUI = !req.headers.authorization;
        if (isUI) {
            (0, metric_events_1.emitMetricEvent)(eventBus, metric_events_1.REQUEST_ORIGIN, {
                type: 'UI',
                method: req.method,
            });
        }
        else {
            logger.info('API request', {
                method: req.method,
                userAgent: req.headers['user-agent'],
            });
            (0, metric_events_1.emitMetricEvent)(eventBus, metric_events_1.REQUEST_ORIGIN, {
                type: 'API',
                method: req.method,
            });
        }
        next();
    };
};
exports.originMiddleware = originMiddleware;
//# sourceMappingURL=origin-middleware.js.map